@@ -1,5 +1,4 @@
 /************************************************************
-
   This example shows how to set the space allocation time
   for a dataset.  The program first creates two datasets,
   one with the default allocation time (late) and one with
@@ -7,9 +6,6 @@
   allocated and their allocation size.  Next, it writes data
   to the datasets, and again displays whether each has been
   allocated and their allocation size.
-
-  This file is intended for use with HDF5 Library verion 1.6
-
  ************************************************************/
 package examples.datasets;
 
@@ -21,7 +17,7 @@ import ncsa.hdf.hdf5lib.H5;
 import ncsa.hdf.hdf5lib.HDF5Constants;
 
 public class H5Ex_D_Alloc {
-	private static String FILENAME = "h5ex_d_alloc.h5";
+	private static String FILENAME = "H5Ex_D_Alloc.h5";
 	private static String DATASETNAME1 = "DS1";
 	private static String DATASETNAME2 = "DS2";
 	private static final int DIM_X = 4;
