@@ -1,5 +1,4 @@
 /************************************************************
-
   This example shows how to create a chunked dataset.  The
   program first writes integers in a hyperslab selection to
   a chunked dataset with dataspace dimensions of DIM_XxDIM_Y
@@ -8,9 +7,6 @@
   outputs it to the screen.  Finally it reads the data again
   using a different hyperslab selection, and outputs
   the result to the screen.
-
-  This file is intended for use with HDF5 Library verion 1.6
-
  ************************************************************/
 package examples.datasets;
 
@@ -22,7 +18,7 @@ import ncsa.hdf.hdf5lib.H5;
 import ncsa.hdf.hdf5lib.HDF5Constants;
 
 public class H5Ex_D_Chunk {
-	private static String FILENAME = "h5ex_d_chunk.h5";
+	private static String FILENAME = "H5Ex_D_Chunk.h5";
 	private static String DATASETNAME = "DS1";
 	private static final int DIM_X = 6;
 	private static final int DIM_Y = 8;
@@ -33,8 +29,7 @@ public class H5Ex_D_Chunk {
 
 	// Values for the status of space allocation
 	enum H5D_layout {
-		H5D_LAYOUT_ERROR(-1), H5D_COMPACT(0), H5D_CONTIGUOUS(1), H5D_CHUNKED(2), H5D_NLAYOUTS(
-				3);
+		H5D_LAYOUT_ERROR(-1), H5D_COMPACT(0), H5D_CONTIGUOUS(1), H5D_CHUNKED(2), H5D_NLAYOUTS(3);
 		private static final Map<Integer, H5D_layout> lookup = new HashMap<Integer, H5D_layout>();
 
 		static {
