@@ -1,13 +1,9 @@
 /************************************************************
-
   This example shows how to read and write data to a compact
   dataset.  The program first writes integers to a compact
   dataset with dataspace dimensions of DIM_XxDIM_Y, then
   closes the file.  Next, it reopens the file, reads back
   the data, and outputs it to the screen.
-
-  This file is intended for use with HDF5 Library verion 1.6
-
  ************************************************************/
 package examples.datasets;
 
@@ -19,7 +15,7 @@ import ncsa.hdf.hdf5lib.H5;
 import ncsa.hdf.hdf5lib.HDF5Constants;
 
 public class H5Ex_D_Compact {
-	private static String FILENAME = "h5ex_d_compact.h5";
+	private static String FILENAME = "H5Ex_D_Compact.h5";
 	private static String DATASETNAME = "DS1";
 	private static final int DIM_X = 4;
 	private static final int DIM_Y = 7;
