@@ -1,5 +1,4 @@
 /************************************************************
-
   This example shows how to create and extend an unlimited
   dataset with gzip compression.  The program first writes
   integers to a gzip compressed dataset with dataspace
@@ -9,9 +8,6 @@
   extended portions of the dataset.  Finally it reopens the
   file again, reads back the data, and outputs it to the
   screen.
-
-  This file is intended for use with HDF5 Library verion 1.6
-
  ************************************************************/
 package examples.datasets;
 
@@ -23,7 +19,7 @@ import ncsa.hdf.hdf5lib.H5;
 import ncsa.hdf.hdf5lib.HDF5Constants;
 
 public class H5Ex_D_UnlimitedGzip {
-    private static String FILENAME = "h5ex_d_unlimgzip.h5";
+    private static String FILENAME = "H5Ex_D_UnlimitedGzip.h5";
     private static String DATASETNAME = "DS1";
     private static final int DIM_X = 4;
     private static final int DIM_Y = 7;
@@ -36,9 +32,11 @@ public class H5Ex_D_UnlimitedGzip {
 
     // Values for the status of space allocation
     enum H5Z_filter {
-        H5Z_FILTER_ERROR(-1), H5Z_FILTER_NONE(0), H5Z_FILTER_DEFLATE(1), H5Z_FILTER_SHUFFLE(
-                2), H5Z_FILTER_FLETCHER32(3), H5Z_FILTER_SZIP(4), H5Z_FILTER_NBIT(5), H5Z_FILTER_SCALEOFFSET(
-                6), H5Z_FILTER_RESERVED(256), H5Z_FILTER_MAX(65535);
+        H5Z_FILTER_ERROR(HDF5Constants.H5Z_FILTER_ERROR), H5Z_FILTER_NONE(HDF5Constants.H5Z_FILTER_NONE), 
+        H5Z_FILTER_DEFLATE(HDF5Constants.H5Z_FILTER_DEFLATE), H5Z_FILTER_SHUFFLE(HDF5Constants.H5Z_FILTER_SHUFFLE), 
+        H5Z_FILTER_FLETCHER32(HDF5Constants.H5Z_FILTER_FLETCHER32), H5Z_FILTER_SZIP(HDF5Constants.H5Z_FILTER_SZIP), 
+        H5Z_FILTER_NBIT(HDF5Constants.H5Z_FILTER_NBIT), H5Z_FILTER_SCALEOFFSET(HDF5Constants.H5Z_FILTER_SCALEOFFSET), 
+        H5Z_FILTER_RESERVED(HDF5Constants.H5Z_FILTER_RESERVED), H5Z_FILTER_MAX(HDF5Constants.H5Z_FILTER_MAX);
         private static final Map<Integer, H5Z_filter> lookup = new HashMap<Integer, H5Z_filter>();
 
         static {
@@ -63,8 +61,7 @@ public class H5Ex_D_UnlimitedGzip {
 
     private static boolean checkGzipFilter() {
         try {
-            int available = H5.H5Zfilter_avail(H5Z_filter.H5Z_FILTER_DEFLATE
-                    .getCode());
+            int available = H5.H5Zfilter_avail(HDF5Constants.H5Z_FILTER_DEFLATE);
             if (available == 0) {
                 System.out.println("gzip filter not available.");
                 return false;
@@ -78,8 +75,7 @@ public class H5Ex_D_UnlimitedGzip {
             int filter_info = H5.H5Zget_filter_info(HDF5Constants.H5Z_FILTER_DEFLATE);
             if (((filter_info & HDF5Constants.H5Z_FILTER_CONFIG_ENCODE_ENABLED) == 0)
                     || ((filter_info & HDF5Constants.H5Z_FILTER_CONFIG_DECODE_ENABLED) == 0)) {
-                System.out
-                        .println("gzip filter not available for encoding and decoding.");
+                System.out.println("gzip filter not available for encoding and decoding.");
                 return false;
             }
         }
@@ -139,7 +135,8 @@ public class H5Ex_D_UnlimitedGzip {
         try {
             if ((file_id >= 0) && (dataspace_id >= 0) && (dcpl_id >= 0))
                 dataset_id = H5.H5Dcreate(file_id, DATASETNAME,
-                        HDF5Constants.H5T_STD_I32LE, dataspace_id, HDF5Constants.H5P_DEFAULT, dcpl_id, HDF5Constants.H5P_DEFAULT);
+                        HDF5Constants.H5T_STD_I32LE, dataspace_id, 
+                        HDF5Constants.H5P_DEFAULT, dcpl_id, HDF5Constants.H5P_DEFAULT);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -149,8 +146,8 @@ public class H5Ex_D_UnlimitedGzip {
         try {
             if (dataset_id >= 0)
                 H5.H5Dwrite(dataset_id, HDF5Constants.H5T_NATIVE_INT,
-                        HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                        HDF5Constants.H5P_DEFAULT, dset_data);
+                        HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL, HDF5Constants.H5P_DEFAULT, 
+                        dset_data);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -204,8 +201,7 @@ public class H5Ex_D_UnlimitedGzip {
 
         // Open an existing file.
         try {
-            file_id = H5.H5Fopen(FILENAME, HDF5Constants.H5F_ACC_RDWR,
-                    HDF5Constants.H5P_DEFAULT);
+            file_id = H5.H5Fopen(FILENAME, HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -246,8 +242,8 @@ public class H5Ex_D_UnlimitedGzip {
         try {
             if (dataset_id >= 0)
                 H5.H5Dread(dataset_id, HDF5Constants.H5T_NATIVE_INT,
-                        HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                        HDF5Constants.H5P_DEFAULT, dset_data);
+                        HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL, HDF5Constants.H5P_DEFAULT, 
+                        dset_data);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -355,8 +351,7 @@ public class H5Ex_D_UnlimitedGzip {
 
         // Open an existing file.
         try {
-            file_id = H5.H5Fopen(FILENAME, HDF5Constants.H5F_ACC_RDONLY,
-                    HDF5Constants.H5P_DEFAULT);
+            file_id = H5.H5Fopen(FILENAME, HDF5Constants.H5F_ACC_RDONLY, HDF5Constants.H5P_DEFAULT);
         }
         catch (Exception e) {
             e.printStackTrace();
@@ -440,8 +435,8 @@ public class H5Ex_D_UnlimitedGzip {
         try {
             if (dataset_id >= 0)
                 H5.H5Dread(dataset_id, HDF5Constants.H5T_NATIVE_INT,
-                        HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL,
-                        HDF5Constants.H5P_DEFAULT, dset_data);
+                        HDF5Constants.H5S_ALL, HDF5Constants.H5S_ALL, HDF5Constants.H5P_DEFAULT, 
+                        dset_data);
         }
         catch (Exception e) {
             e.printStackTrace();
