@@ -16,7 +16,7 @@ import ncsa.hdf.hdf5lib.H5;
 import ncsa.hdf.hdf5lib.HDF5Constants;
 
 public class H5Ex_T_BitAttribute {
-	private static String FILENAME = "h5ex_t_bitatt.h5";
+	private static String FILENAME = "H5Ex_T_BitAttribute.h5";
 	private static String DATASETNAME = "DS1";
 	private static String ATTRIBUTENAME = "A1";
 	private static final int DIM0 = 4;
@@ -77,9 +77,9 @@ public class H5Ex_T_BitAttribute {
 		// Create the attribute and write the array data to it.
 		try {
 			if ((dataset_id >= 0) && (dataspace_id >= 0))
-				attribute_id = H5
-						.H5Acreate(dataset_id, ATTRIBUTENAME, HDF5Constants.H5T_STD_B8BE,
-								dataspace_id, HDF5Constants.H5P_DEFAULT);
+				attribute_id = H5.H5Acreate(dataset_id, ATTRIBUTENAME, 
+				        HDF5Constants.H5T_STD_B8BE, dataspace_id, 
+				        HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
 		}
 		catch (Exception e) {
 			e.printStackTrace();
@@ -141,8 +141,7 @@ public class H5Ex_T_BitAttribute {
 
 		// Open an existing file.
 		try {
-			file_id = H5.H5Fopen(FILENAME, HDF5Constants.H5F_ACC_RDONLY,
-					HDF5Constants.H5P_DEFAULT);
+			file_id = H5.H5Fopen(FILENAME, HDF5Constants.H5F_ACC_RDONLY, HDF5Constants.H5P_DEFAULT);
 		}
 		catch (Exception e) {
 			e.printStackTrace();
@@ -159,7 +158,8 @@ public class H5Ex_T_BitAttribute {
 
 		try {
 			if (dataset_id >= 0)
-				attribute_id = H5.H5Aopen_name(dataset_id, ATTRIBUTENAME);
+                attribute_id = H5.H5Aopen_by_name(dataset_id, ".", ATTRIBUTENAME, 
+                        HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
 		}
 		catch (Exception e) {
 			e.printStackTrace();
