@@ -21,7 +21,7 @@ import ncsa.hdf.hdf5lib.H5;
 import ncsa.hdf.hdf5lib.HDF5Constants;
 
 public class H5Ex_T_ObjectReferenceAttribute {
-	private static String FILENAME = "h5ex_t_objrefatt.h5";
+	private static String FILENAME = "H5Ex_T_ObjectReferenceAttribute.h5";
 	private static String DATASETNAME = "DS1";
 	private static String ATTRIBUTENAME = "A1";
 	private static String DATASETNAME2 = "DS2";
@@ -31,15 +31,15 @@ public class H5Ex_T_ObjectReferenceAttribute {
 
 	// Values for the status of space allocation
 	enum H5G_obj {
-		H5G_UNKNOWN(-1), /* Unknown object type */
-		H5G_GROUP(0), /* Object is a group */
-		H5G_DATASET(1), /* Object is a dataset */
-		H5G_TYPE(2), /* Object is a named data type */
-		H5G_LINK(3), /* Object is a symbolic link */
-		H5G_UDLINK(4), /* Object is a user-defined link */
-		H5G_RESERVED_5(5), /* Reserved for future use */
-		H5G_RESERVED_6(6), /* Reserved for future use */
-		H5G_RESERVED_7(7); /* Reserved for future use */
+		H5G_UNKNOWN(HDF5Constants.H5G_UNKNOWN), /* Unknown object type */
+		H5G_GROUP(HDF5Constants.H5G_GROUP), /* Object is a group */
+		H5G_DATASET(HDF5Constants.H5G_DATASET), /* Object is a dataset */
+		H5G_TYPE(HDF5Constants.H5G_TYPE), /* Object is a named data type */
+		H5G_LINK(HDF5Constants.H5G_LINK), /* Object is a symbolic link */
+		H5G_UDLINK(HDF5Constants.H5G_UDLINK), /* Object is a user-defined link */
+		H5G_RESERVED_5(HDF5Constants.H5G_RESERVED_5), /* Reserved for future use */
+		H5G_RESERVED_6(HDF5Constants.H5G_RESERVED_6), /* Reserved for future use */
+		H5G_RESERVED_7(HDF5Constants.H5G_RESERVED_7); /* Reserved for future use */
 		private static final Map<Integer, H5G_obj> lookup = new HashMap<Integer, H5G_obj>();
 
 		static {
@@ -101,7 +101,8 @@ public class H5Ex_T_ObjectReferenceAttribute {
 		// Create a group in the file.
 		try {
 			if (file_id >= 0)
-				group_id = H5.H5Gcreate(file_id, GROUPNAME, HDF5Constants.H5P_DEFAULT);
+				group_id = H5.H5Gcreate(file_id, GROUPNAME, 
+				        HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
 			if (group_id >= 0)
 				H5.H5Gclose(group_id);
 			group_id = -1;
@@ -115,10 +116,8 @@ public class H5Ex_T_ObjectReferenceAttribute {
 		// besides valid dataspaces result in an error.
 		try {
 			if (file_id >= 0) {
-				byte rbuf0[] = H5.H5Rcreate(file_id, GROUPNAME,
-						HDF5Constants.H5R_OBJECT, -1);
-				byte rbuf1[] = H5.H5Rcreate(file_id, DATASETNAME2,
-						HDF5Constants.H5R_OBJECT, -1);
+				byte rbuf0[] = H5.H5Rcreate(file_id, GROUPNAME, HDF5Constants.H5R_OBJECT, -1);
+				byte rbuf1[] = H5.H5Rcreate(file_id, DATASETNAME2, HDF5Constants.H5R_OBJECT, -1);
 				for (int indx = 0; indx < 8; indx++) {
 					dset_data[0][indx] = rbuf0[indx];
 					dset_data[1][indx] = rbuf1[indx];
@@ -159,7 +158,7 @@ public class H5Ex_T_ObjectReferenceAttribute {
 			if ((dataset_id >= 0) && (dataspace_id >= 0))
 				attribute_id = H5.H5Acreate(dataset_id, ATTRIBUTENAME,
 						HDF5Constants.H5T_STD_REF_OBJ, dataspace_id,
-						HDF5Constants.H5P_DEFAULT);
+						HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
 		}
 		catch (Exception e) {
 			e.printStackTrace();
@@ -223,8 +222,7 @@ public class H5Ex_T_ObjectReferenceAttribute {
 
 		// Open an existing file.
 		try {
-			file_id = H5.H5Fopen(FILENAME, HDF5Constants.H5F_ACC_RDONLY,
-					HDF5Constants.H5P_DEFAULT);
+			file_id = H5.H5Fopen(FILENAME, HDF5Constants.H5F_ACC_RDONLY, HDF5Constants.H5P_DEFAULT);
 		}
 		catch (Exception e) {
 			e.printStackTrace();
@@ -241,7 +239,8 @@ public class H5Ex_T_ObjectReferenceAttribute {
 
 		try {
 			if (dataset_id >= 0)
-				attribute_id = H5.H5Aopen_name(dataset_id, ATTRIBUTENAME);
+				attribute_id = H5.H5Aopen_by_name(dataset_id, ".", ATTRIBUTENAME, 
+				        HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT);
 		}
 		catch (Exception e) {
 			e.printStackTrace();
@@ -284,10 +283,9 @@ public class H5Ex_T_ObjectReferenceAttribute {
 			// Open the referenced object, get its name and type.
 			try {
 				if (dataset_id >= 0) {
-					object_id = H5.H5Rdereference(dataset_id, HDF5Constants.H5R_OBJECT,
-							dset_data[indx]);
-					object_type = H5.H5Rget_obj_type(dataset_id,
-							HDF5Constants.H5R_OBJECT, dset_data[indx]);
+			        int[] otype = { 1 };
+					object_id = H5.H5Rdereference(dataset_id, HDF5Constants.H5R_OBJECT, dset_data[indx]);
+					object_type = H5.H5Rget_obj_type(dataset_id, HDF5Constants.H5R_OBJECT, dset_data[indx], otype);
 				}
 				String[] obj_name = new String[1];
 				long name_size = 1;
