@@ -26,14 +26,16 @@ extern "C" {
 
 
 #include "hdf.h"
-#include <jni.h>
+#include "jni.h"
 
 #ifdef __cplusplus
 #define ENVPTR (env)
 #define ENVPAR
+#define ENVONLY
 #else
 #define ENVPTR (*env)
 #define ENVPAR env,
+#define ENVONLY env
 #endif
 
 extern jboolean h4outOfMemory( JNIEnv *env, char *functName);
