@@ -14,9 +14,22 @@
 
 package ncsa.hdf.object.h4;
 
-import java.util.*;
-import ncsa.hdf.hdflib.*;
-import ncsa.hdf.object.*;
+import java.util.List;
+import java.util.Vector;
+
+import ncsa.hdf.hdflib.HDFChunkInfo;
+import ncsa.hdf.hdflib.HDFCompInfo;
+import ncsa.hdf.hdflib.HDFConstants;
+import ncsa.hdf.hdflib.HDFDeflateCompInfo;
+import ncsa.hdf.hdflib.HDFException;
+import ncsa.hdf.hdflib.HDFLibrary;
+import ncsa.hdf.object.Attribute;
+import ncsa.hdf.object.Dataset;
+import ncsa.hdf.object.Datatype;
+import ncsa.hdf.object.FileFormat;
+import ncsa.hdf.object.Group;
+import ncsa.hdf.object.HObject;
+import ncsa.hdf.object.ScalarDS;
 
 /**
  * H4GRImage describes HDF4 general raster(GR) image and operations performed on
@@ -89,7 +102,10 @@ import ncsa.hdf.object.*;
  */
 public class H4GRImage extends ScalarDS
 {
-	public static final long serialVersionUID = HObject.serialVersionUID;
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 1029672744963360976L;
 
     /**
      * The list of attributes of this data object. Members of the list are
@@ -163,6 +179,7 @@ public class H4GRImage extends ScalarDS
     }
 
     // To do: Implementing Dataset
+    @Override
     public Dataset copy(Group pgroup, String dname, long[] dims, Object buff) throws Exception
     {
         Dataset dataset = null;
@@ -260,12 +277,15 @@ public class H4GRImage extends ScalarDS
     }
 
     // ***** need to implement from ScalarDS *****
+    @Override
     public byte[][] readPalette(int idx) { return null;}
 
     // ***** need to implement from ScalarDS *****
+    @Override
     public byte[] getPaletteRefs() { return null;}
 
     // implementing ScalarDS
+    @Override
     public Datatype getDatatype()
     {
         if (datatype == null)
@@ -277,6 +297,7 @@ public class H4GRImage extends ScalarDS
     }
 
     // Implementing Dataset
+    @Override
     public byte[] readBytes() throws HDFException
     {
         byte[] theData = null;
@@ -318,6 +339,7 @@ public class H4GRImage extends ScalarDS
     }
 
     // ***** need to implement from DataFormat *****
+    @Override
     public Object read() throws HDFException
     {
         Object theData = null;
@@ -371,6 +393,7 @@ public class H4GRImage extends ScalarDS
     }
 
     // Implementing DataFormat
+    @Override
     public void write(Object buf) throws HDFException
     {
         if (buf == null) {
@@ -506,6 +529,7 @@ public class H4GRImage extends ScalarDS
     public void removeMetadata(Object info) throws HDFException {;}
 
     // Implementing HObject.
+    @Override
     public int open()
     {
 
@@ -522,6 +546,7 @@ public class H4GRImage extends ScalarDS
     }
 
     // Implementing HObject.
+    @Override
     public void close(int grid)
     {
         try { HDFLibrary.GRendaccess(grid); }
@@ -529,6 +554,7 @@ public class H4GRImage extends ScalarDS
     }
 
     // Implementing Dataset.
+    @Override
     public void init()
     {
         if (rank>0) {
@@ -613,6 +639,7 @@ public class H4GRImage extends ScalarDS
     }
 
     // ***** need to implement from ScalarDS *****
+    @Override
     public byte[][] getPalette()
     {
         if (palette != null) {
@@ -875,4 +902,9 @@ public class H4GRImage extends ScalarDS
         } catch (Exception ex) {}
     }
 
+    //Implementing DataFormat
+    public List getMetadata(int... attrPropList) throws Exception {
+        throw new UnsupportedOperationException("getMetadata(int... attrPropList) is not supported");
+    }
+
 }
