@@ -14,9 +14,17 @@
 
 package ncsa.hdf.object.h4;
 
-import java.util.*;
-import ncsa.hdf.hdflib.*;
-import ncsa.hdf.object.*;
+import java.util.List;
+import java.util.Vector;
+
+import ncsa.hdf.hdflib.HDFConstants;
+import ncsa.hdf.hdflib.HDFException;
+import ncsa.hdf.hdflib.HDFLibrary;
+import ncsa.hdf.object.Attribute;
+import ncsa.hdf.object.CompoundDS;
+import ncsa.hdf.object.Dataset;
+import ncsa.hdf.object.Datatype;
+import ncsa.hdf.object.FileFormat;
 
 /**
  * H4Vdata describes a multi-dimension array of HDF4 vdata, inheriting CompoundDS.
@@ -81,7 +89,10 @@ import ncsa.hdf.object.*;
  */
 public class H4Vdata extends CompoundDS
 {
-	public static final long serialVersionUID = HObject.serialVersionUID;
+    /**
+     * 
+     */
+    private static final long serialVersionUID = -5978700886955419959L;
 
     /**
      * The list of attributes of this data object. Members of the list are
@@ -145,6 +156,7 @@ public class H4Vdata extends CompoundDS
     }
     
     // implementing Dataset
+    @Override
     public Datatype getDatatype()
     {
         if (datatype == null)
@@ -156,6 +168,7 @@ public class H4Vdata extends CompoundDS
     }
 
     // Implementing Dataset
+    @Override
     public byte[] readBytes() throws HDFException
     {
         byte[] theData = null;
@@ -200,6 +213,7 @@ public class H4Vdata extends CompoundDS
     }
 
     // Implementing DataFormat
+    @Override
     public Object read() throws HDFException
     {
         List list = null;
@@ -288,6 +302,7 @@ public class H4Vdata extends CompoundDS
     }
 
     // Implementing DataFormat
+    @Override
     public void write(Object buf) throws HDFException
     {
         //For writing to a vdata, VSsetfields can only be called once, to set
@@ -444,6 +459,7 @@ public class H4Vdata extends CompoundDS
     public void removeMetadata(Object info) throws HDFException { ; }
 
     // Implementing DataFormat
+    @Override
     public int open()
     {
         int vsid = -1;
@@ -471,6 +487,7 @@ public class H4Vdata extends CompoundDS
     }
 
     // Implementing DataFormat
+    @Override
     public void close(int vsid)
     {
         try { HDFLibrary.VSdetach(vsid); }
@@ -480,6 +497,7 @@ public class H4Vdata extends CompoundDS
     /**
      * Initializes the H4Vdata such as dimension sizes of this dataset.
      */
+    @Override
     public void init()
     {
         if (rank>0) {
@@ -565,4 +583,9 @@ public class H4Vdata extends CompoundDS
     {
         return memberOrders;
     }
+
+    //Implementing DataFormat
+    public List getMetadata(int... attrPropList) throws Exception {
+        throw new UnsupportedOperationException("getMetadata(int... attrPropList) is not supported");
+    }
 }
