@@ -51,12 +51,8 @@ public class TestH5D {
         File file = new File(filename);
 
         if (file.exists()) {
-            try {
-                file.delete();
-            }
-            catch (SecurityException e) {
-                ;// e.printStackTrace();
-            }
+            try {file.delete();}
+            catch (SecurityException e) {}
         }
     }
 
@@ -129,17 +125,17 @@ public class TestH5D {
     
     private final void _closeH5file() throws HDF5LibraryException {
         if (H5dcpl_id >= 0)
-            H5.H5Pclose(H5dcpl_id);
+            try {H5.H5Pclose(H5dcpl_id);} catch (Exception ex) {}
         if (H5did0 >= 0)
-            H5.H5Dclose(H5did0);
+            try {H5.H5Dclose(H5did0);} catch (Exception ex) {}
         if (H5did >= 0)
-            H5.H5Dclose(H5did);
+            try {H5.H5Dclose(H5did);} catch (Exception ex) {}
         if (H5dtid > 0) 
-            H5.H5Tclose(H5dtid);
+            try {H5.H5Tclose(H5dtid);} catch (Exception ex) {}
         if (H5dsid > 0) 
-            H5.H5Sclose(H5dsid);
+            try {H5.H5Sclose(H5dsid);} catch (Exception ex) {}
         if (H5fid > 0) 
-            H5.H5Fclose(H5fid);
+            try {H5.H5Fclose(H5fid);} catch (Exception ex) {}
     }
 
     private final void _openH5file(String name, int dapl) {
@@ -180,17 +176,17 @@ public class TestH5D {
     @After
     public void deleteH5file() throws HDF5LibraryException {
         if (H5dcpl_id >= 0)
-            H5.H5Pclose(H5dcpl_id);
+            try {H5.H5Pclose(H5dcpl_id);} catch (Exception ex) {}
         if (H5did0 >= 0)
-            H5.H5Dclose(H5did0);
+            try {H5.H5Dclose(H5did0);} catch (Exception ex) {}
         if (H5did >= 0)
-            H5.H5Dclose(H5did);
+            try {H5.H5Dclose(H5did);} catch (Exception ex) {}
         if (H5dtid > 0) 
-            H5.H5Tclose(H5dtid);
+            try {H5.H5Tclose(H5dtid);} catch (Exception ex) {}
         if (H5dsid > 0) 
-            H5.H5Sclose(H5dsid);
+            try {H5.H5Sclose(H5dsid);} catch (Exception ex) {}
         if (H5fid > 0) 
-            H5.H5Fclose(H5fid);
+            try {H5.H5Fclose(H5fid);} catch (Exception ex) {}
 
         _deleteFile(H5_FILE);
     }
